@@ -20,7 +20,7 @@ trust a code translator, this is your library.
 
 
 __title__ = 'oct2py'
-__version__ = '1.5.0'
+__version__ = '1.6.0'
 __author__ = 'Steven Silvester'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014 Steven Silvester'
@@ -44,6 +44,22 @@ try:
 except Oct2PyError as e:
     print(e)
 
+
+def kill_octave():
+    """Kill all octave instances (cross-platform).
+
+    This will restart the "octave" instance.  If you have instantiated
+    Any other Oct2Py objects, you must restart them.
+    """
+    import os
+    if os.name == 'nt':
+        os.system('taskkill /im octave /f')
+    else:
+        os.system('killall -9 octave')
+        os.system('killall -9 octave-cli')
+    octave.restart()
+
+
 # clean up namespace
 del functools, imp, os
 try:
